=================
AiiDA metapackage
=================

This metapackage will install aiida-core alongside with commonly used plugins.
It is meant as a starting point for new users and users who are using mainly the plugins which originally were part of previous aiida versions.
